/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import {Component, Input, OnInit} from '@angular/core';
import {Image} from "../model/image";
import {ActivatedRoute, Router} from "@angular/router";
import {Subscription} from "rxjs";
import {SelectedFilterService} from "../services/selected-filter.service";
import {SelectedFilter} from "../model/selected-filter";

@Component({
  selector: 'app-image-results',
  templateUrl: './image-results.component.html',
  styleUrls: ['./image-results.component.scss']
})
export class ImageResultsComponent implements OnInit {

  @Input() searchResults: Array<Image> = [];
  public sortCol: string = '';
  public sortAsc: boolean = true;

  public selectedFilters: Array<SelectedFilter>;
  public selectedFiltersSub: Subscription;

  constructor( private selectedFilterService: SelectedFilterService, private router: Router, private route: ActivatedRoute) {}

  ngOnInit() {
    this.selectedFiltersSub = this.selectedFilterService.selectedFilters$.subscribe( selectedFilters => {
      this.selectedFilters = selectedFilters;
      for(let filter of this.selectedFilters){
        if(filter.name == 'sort') {
          let sortParts = filter.value.split('+');
          this.sortCol = sortParts[0];
          this.sortAsc = (sortParts[1] === 'asc');
        }
      }
    });
  }

  setSort(field: string){
    if(field == this.sortCol){
      this.sortAsc = !this.sortAsc;
    } else {
      this.sortAsc = true;
    }
    this.sortCol = field;
    this.router.navigate([], { relativeTo: this.route, queryParams: { sort: field + (this.sortAsc ? '+asc' : '+desc')}, queryParamsHandling: "merge" });

  }


  getLat(latLng: string){
    let coords = latLng.split(',');
    return parseFloat(coords[0]);
  }

  getLng(latLng: string){
    let coords = latLng.split(',');
    return parseFloat(coords[1]) + 180;
  }

}
