"""correcting restore script name error

Revision ID: 10251d1732a4
Revises: d3abd475fbb4
Create Date: 2021-07-19 10:16:51.226070

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "10251d1732a4"
down_revision = "d3abd475fbb4"
branch_labels = None
depends_on = None


condor_content = """executable = restore_cms.sh
arguments = {{product_locator}} {{cal_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""

script_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../
./casa_envoy --restore -c $4 $5
cp -r ./working/{{sdmId}}.ms ./products/
./deliver -p ./products --prefix $3

"""


old_content = """executable = std_restore_imaging.sh
arguments = {{product_locator}} {{cal_product_locator}} {{request_id}} metadata.json PPR.xml

output = restore.out
error = restore.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/.matplotlib, $(SBIN_PATH)/pycapo, $(SBIN_PATH)/framework.sh, $(SBIN_PATH)/productfetcher, $(SBIN_PATH)/casa_envoy, $(SBIN_PATH)/vela, $(SBIN_PATH)/deliver, ./PPR.xml, ./metadata.json
transfer_output_files = working, rawdata, products

request_memory = {{ramInGb}}
getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue


"""

old_script_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../
./casa_envoy --restore -c $4 $5
cp ./working/{{sdmId}}.ms ./products/
./deliver -p ./products --prefix $3

"""


def upgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{condor_content}' where filename = 'restore_cms.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{script_content}' where filename = 'restore_cms.sh'
        """
    )


def downgrade():
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{old_content}' where filename = 'restore_cms.condor'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{script_content}' where filename = 'restore_cms.sh'
        """
    )
