#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

# pylint: disable=C0114, C0115, C0116, R0903

from __future__ import annotations


class ActionIF:
    """
    An action to take upon performing a transition. We expect to see several implementations
    of this interface:

    - SendNotification(template, additional_args) that sends a notification with
      the event and additional arguments

    - StartWorkflow(workflow_name, additional_args) that starts a workflow with the
      provided name, the event and additional arguments
    """

    def __call__(self, execution: "CapabilityExecution", manager):
        """
        Do something interesting during a state change.

        :param execution:
        :param manager:
        :return:
        """
        raise NotImplementedError

    def resume(self, execution: "CapabilityExecution", manager):
        """
        Resume work from this state, if we were queued for some reason
        :param execution: the execution in question
        :param manager:   the manager
        :return:
        """
